@@ -489,7 +489,7 @@ class kafka_mdml_consumer:
                         'parts': part_info[1],
                         part_info[0]: value['chunk'] 
                     }
-                if part_info == 1:
+                if part_info[0] == 1:
                     files[fn]['time'] = value['time']
                 if len(files[fn].keys()) == (int(files[fn]['parts']) + 1):
                     dat = ''
